@@ -29,7 +29,7 @@
 
 //-1 Not worked, 0 = worked, 1 = confirmed
 AwardDXCC::AwardDXCC(){
-// cout << "AwardDXCC::AwardDXCC" << endl;
+////cout << "AwardDXCC::AwardDXCC" << endl;
 	i = 0;
 	j = 0;
 	k = 0;
@@ -46,11 +46,11 @@ AwardDXCC::AwardDXCC(){
 }
 
 AwardDXCC::~AwardDXCC(){
-//cout << "AwardDXCC::~AwardDXCC" << endl;
+////cout << "AwardDXCC::~AwardDXCC" << endl;
 }
 
 void AwardDXCC::clear(){
-//cout << "AwardDXCC::clear" << endl;
+////cout << "AwardDXCC::clear" << endl;
   i = 0;
   j = 0;
   k = 0;
@@ -67,7 +67,7 @@ void AwardDXCC::clear(){
 }
 
 void AwardDXCC::worked(const int tentity, const int tband, const int tmode){
-//cout << "AwardDXCC::worked: " << QString::number(tentity) << "/"  << QString::number(tband) << "/"  << QString::number(tmode) << "/" << endl;
+////cout << "AwardDXCC::worked: " << QString::number(tentity) << "/"  << QString::number(tband) << "/"  << QString::number(tmode) << "/" << endl;
 	i = tentity;
 	j = tband;
 	k = tmode;
@@ -80,31 +80,34 @@ void AwardDXCC::worked(const int tentity, const int tband, const int tmode){
 
 }
 
-void AwardDXCC::workedString(const int tentity, const QString& tband, const QString& tmode){
-//cout << "AwardDXCC::workedString" << endl;
+void AwardDXCC::workedString(const int tentity, const QString& tband,const QString& tmode){
+////cout << "AwardDXCC::workedString: Entity: " << QString::number(tentity)<< "/Band: " << tband << "/Mode: " << tmode << endl;
 	i = tentity;
-	sAux = tband;
-	j = adif.band2Int(sAux);
-	if (j == -1)
+	//AwardDXCC::sAux = tband;
+	j = adif.band2Int(tband);
+	if (j == -1){
 		return;
-	sAux = tmode;
-	k = adif.mode2Int(sAux);
-	if (k == -1)
+	}
+	//sAux = tmode;
+	k = adif.mode2Int(tmode);
+	if (k == -1){
 		return;
-
-	if ( dxccb[i][j] != 1)
+	}
+	if ( dxccb[i][j] != 1){
 		dxccb[i][j] = 0;
-	if ( dxccm[i][k] != 1)
+	}
+	if ( dxccm[i][k] != 1){
 		dxccm[i][k] = 0;
+	}
 	dxccW[i] = true;
 //  dxccCountWorked++;
 
 }
 
 void AwardDXCC::notWorked(const int tentity, const int tband, const int tmode){
-// cout << "AwardDXCC::notWorked" << endl;
-  //Needs to have a way to check if it
-// cout << "AwardDXCC::notWorked: Enti/Band/Mode: " << QString::number(tentity) <<"/"<< QString::number(tband) <<"/"<< QString::number(tmode)<< endl;
+//cout << "AwardDXCC::notWorked: Entity: " << QString::number(tentity)<< "/Band: " << tband << "/Mode: " << tmode << endl;
+//Needs to have a way to check if it
+// //cout << "AwardDXCC::notWorked: Enti/Band/Mode: " << QString::number(tentity) <<"/"<< QString::number(tband) <<"/"<< QString::number(tmode)<< endl;
 	i = tentity;
 	j = tband;
 	k = tmode;
@@ -115,14 +118,14 @@ void AwardDXCC::notWorked(const int tentity, const int tband, const int tmode){
 }
 
 void AwardDXCC::notWorkedString(const int tentity, const QString& tband, const QString& tmode){
-// cout << "AwardDXCC::notWorkedString" << endl;
+//cout << "AwardDXCC::notWorkedString: Entity: " << QString::number(tentity)<< "/Band: " << tband << "/Mode: " << tmode << endl;
 	i = tentity;
-	sAux = tband;
-	j = adif.band2Int(sAux);
+	//sAux = tband;
+	j = adif.band2Int(tband);
 	if (j == -1)
 		return;
-	sAux = tmode;
-	k = adif.mode2Int(sAux);
+	//sAux = tmode;
+	k = adif.mode2Int(tmode);
 	if (k == -1)
 		return;
 
@@ -136,13 +139,13 @@ void AwardDXCC::notWorkedString(const int tentity, const QString& tband, const Q
 
 
 bool AwardDXCC::isWorked(const int tentity){
-// cout << "AwardDXCC::isWorked" << endl;
+//cout << "AwardDXCC::isWorked; " << QString::number(tentity) << endl;
 	i = tentity;
 	return dxccW[i];
 }
 
 bool AwardDXCC::isWorkedBand (const int tentity, const int tband){
-// cout << "AwardDXCC::isWorkedBand" << endl;
+//cout << "AwardDXCC::isWorkedBand: Entity: " << QString::number(tentity) << "/Band: " << QString::number(tband) << endl;
 	i = tentity;
 	j = tband;
 //	if (!dxccW[i])
@@ -154,7 +157,8 @@ bool AwardDXCC::isWorkedBand (const int tentity, const int tband){
 }
 
 bool AwardDXCC::isWorkedMode (const int tentity, const int tmode){
-// cout << "AwardDXCC::isWorkedMode" << endl;
+// //cout << "AwardDXCC::isWorkedMode" << endl;
+//cout << "AwardDXCC::isWorkedMode: Entity: " << QString::number(tentity) << "/Band: " << QString::number(tmode)<< endl;
 	i = tentity;
 	k = tmode;
 //	if (!dxccW[i])
@@ -166,7 +170,7 @@ bool AwardDXCC::isWorkedMode (const int tentity, const int tmode){
 }
 
 int AwardDXCC::howManyWorkedBand(const int tband){
-// cout << "AwardDXCC::howManyWorkedBand" << endl;
+//cout << "AwardDXCC::howManyWorkedBand: " << QString::number(tband) << endl;
 	iAux = 0;
 	j = tband;
 	for (i = 0; i < ENTITIES; i++){
@@ -178,7 +182,7 @@ int AwardDXCC::howManyWorkedBand(const int tband){
 }
 
 int AwardDXCC::howManyWorkedMode(const int tmode){
-// cout << "AwardDXCC::howManyWorkedMode" << endl;
+//cout << "AwardDXCC::howManyWorkedMode: " << QString::number(tmode)<< endl;
   iAux = 0;
   k = tmode;
   for (i = 0; i < ENTITIES; i++){
@@ -196,9 +200,9 @@ int AwardDXCC::howManyWorked(){
 	for (i = 0; i < ENTITIES; i++){
 		if (dxccW[i] == true){
 			iAux++;}
-			//cout << "AwardDXCC::howManyWorked enti/iAux: " << QString::number(i) <<"/"<< QString::number(iAux) << endl;
+			////cout << "AwardDXCC::howManyWorked enti/iAux: " << QString::number(i) <<"/"<< QString::number(iAux) << endl;
 	}
-// cout << "AwardDXCC::howManyWorked: " << QString::number(iAux) << endl;
+// //cout << "AwardDXCC::howManyWorked: " << QString::number(iAux) << endl;
 	return iAux;
 //  return  dxccCountWorked;
 }
@@ -208,7 +212,7 @@ int AwardDXCC::howManyWorked(){
 // CONFIRMED
 
 void AwardDXCC::confirmed(const int tentity, const int tband, const int tmode){
-// cout << "AwardDXCC::confirmed" << endl;
+//cout << "AwardDXCC::confirmed: Entity: " << QString::number(tentity) << "/Band: " << QString::number(tband) << QString::number(tmode)<< endl;
 	i = tentity;
 	j = tband;
 	k = tmode;
@@ -218,15 +222,15 @@ void AwardDXCC::confirmed(const int tentity, const int tband, const int tmode){
 }
 
 void AwardDXCC::confirmedString(const int tentity, const QString& tband, const QString& tmode){
-//cout << "AwardDXCC::confirmedString" << endl;
+//cout << "AwardDXCC::confirmedString: Entity: " << QString::number(tentity) << "/Band: " << tband << "/Mode: " << tmode << endl;
 	i = tentity;
 
-	sAux = tband;
-	j = adif.band2Int(sAux);
+	//sAux = tband;
+	j = adif.band2Int(tband);
 	if (j == -1)
 		return;
-	sAux = tmode;
-	k = adif.mode2Int(sAux);
+	//sAux = tmode;
+	k = adif.mode2Int(tmode);
 	if (k == -1)
 		return;
 
@@ -238,7 +242,7 @@ void AwardDXCC::confirmedString(const int tentity, const QString& tband, const Q
 
 
 bool AwardDXCC::isConfirmed(const int tentity){
-// cout << "AwardDXCC::isConfirmed" << endl;
+//cout << "AwardDXCC::isConfirmed: " << QString::number(tentity) << endl;
 	i = tentity;
 	return dxccC[i];
 }
@@ -257,7 +261,7 @@ bool AwardDXCC::isConfirmedBand (const int tentity, const int tband){
 }
 
 bool AwardDXCC::isConfirmedMode (const int tentity, const int tmode){
-// cout << "AwardDXCC::isConfirmedMode" << endl;
+//cout << "AwardDXCC::isConfirmedMode: " << QString::number(tentity) << "/" << QString::number(tmode) << endl;
 	i = tentity;
 	k = tmode;
 //	if (!dxccC[i])
@@ -270,7 +274,7 @@ bool AwardDXCC::isConfirmedMode (const int tentity, const int tmode){
 }
 
 int AwardDXCC::howManyConfirmedBand(const int tband){
-// cout << "AwardDXCC::howManyConfirmedBand" << endl;
+//cout << "AwardDXCC::howManyConfirmedBand: " << QString::number(tband) << endl;
 	iAux = 0;
 	j = tband;
 	for (i = 0; i < ENTITIES; i++){
@@ -282,7 +286,7 @@ int AwardDXCC::howManyConfirmedBand(const int tband){
 }
 
 int AwardDXCC::howManyConfirmedMode(const int tmode){
-// cout << "AwardDXCC::howManyConfirmed" << endl;
+//cout << "AwardDXCC::howManyConfirmedMode"  << QString::number(tmode) << endl;
 	iAux = 0;
 	k = tmode;
 	for (i = 0; i < ENTITIES; i++){
@@ -295,7 +299,7 @@ int AwardDXCC::howManyConfirmedMode(const int tmode){
 }
 
 int AwardDXCC::howManyConfirmed(){
-// cout << "AwardDXCC::howManyConfirmed" << endl;
+//cout << "AwardDXCC::howManyConfirmed" << endl;
 	iAux = 0;
 	for (i = 0; i < ENTITIES; i++){
 		if (dxccC[i]==true)
@@ -306,7 +310,7 @@ int AwardDXCC::howManyConfirmed(){
 
 
  void AwardDXCC::notConfirmed(const int tentity, const int tband, const int tmode){
-// cout << "AwardDXCC::notConfirmed" << endl;
+//cout << "AwardDXCC::notConfirmed: e:" << QString::number(tentity) << "/b:" << QString::number(tband) << "/m:"<< QString::number(tmode) << endl;
   //Needs to have a way to check if it
   i = tentity;
   j = tband;
@@ -318,15 +322,15 @@ int AwardDXCC::howManyConfirmed(){
 }
 
 void AwardDXCC::notConfirmedString(const int tentity, const QString& tband, const QString& tmode){
-// cout << "AwardDXCC::notConfirmedString" << endl;
+//cout << "AwardDXCC::notConfirmedString: e:" << tentity << "/b:" << tband << "/m:"<< tmode << endl;
   i = tentity;
 
-  sAux = tband;
-  j = adif.band2Int(sAux);
+  //sAux = tband;
+  j = adif.band2Int(tband);
   if (j == -1)
     return;
-  sAux = tmode;
-  k = adif.mode2Int(sAux);
+  //sAux = tmode;
+  k = adif.mode2Int(tmode);
   if (k == -1)
     return;
   dxccb[i][j] = 0;
