@@ -101,53 +101,77 @@ Qso::~Qso(){
 }
 
 void Qso::setQrz(const QString &tqrz ){
-
-  qrz = checkisNotAdif(tqrz);
+//	cout << "QSO::setQrz: " << tqrz << endl;
+	qrz = checkisNotAdif(tqrz);
 }
 
 QString Qso::getQrz() const {
-  return qrz;
+//	cout << "QSO::getQrz " << endl;
+	return qrz;
 }
 
 
 void Qso::setNumb (int tnumb){
-  numb = tnumb  ;
+//	cout << "QSO::setNumb: " << QString::number(tnumb) << endl;
+	numb = tnumb  ;
 }
 
 int Qso::getNumb() const{
-    return numb;}
+//	cout << "QSO::getNumb: " << QString::number(numb) <<endl;
+	return numb;
+}
 
 void Qso::setDateTime(QDateTime tdateTime){
-    dateTime = tdateTime;}
+	//cout << "QSO::setDateTime: " << tdateTime.toString() << endl;
+	dateTime = tdateTime;
+}
 
-QDateTime Qso::getDateTime() const{return dateTime;}
+QDateTime Qso::getDateTime() const{
+	//cout << "QSO::getDateTime: " << dateTime.toString() <<endl;
+	return dateTime;}
 
 void Qso::setRstrx(int trstrx){
-    rstrx = trstrx;  
+//	cout << "QSO::setRstrx: " << QString::number(trstrx) <<endl;
+	rstrx = trstrx;
 }
 
 int Qso::getRstrx() const{
-    return rstrx;}
+//	cout << "QSO::getRstrx: " << QString::number(rstrx) <<endl;	
+    return rstrx;
+}
 
 void Qso::setRsttx(int trsttx){
-    rsttx = trsttx;
+//	cout << "QSO::setRsttx: " << QString::number(trsttx) << endl;
+	rsttx = trsttx;
 }
 
 int Qso::getRsttx() const{
-    return rsttx;}
+//	cout << "QSO::getRsttx: " << QString::number(rsttx) << endl;
+	return rsttx;
+}
 
 void Qso::setBand (const QString& tband){
-    band = checkisNotAdif(tband);
+//TODO: I may set also a default freq per band when calling this function
+// 14000 when 20m, 21000 when 15m and so on...
+	//cout << "QSO::setBand: " << tband << endl;
+	band = checkisNotAdif(tband);
 }
 
 QString Qso::getBand() const{
-    return band;}
+	//cout << "QSO::getBand: " << band << endl;
+	return band;
+}
 
 void Qso::setFreq (const QString& tfreq){
-    freq = checkisNotAdif(tfreq);}
+//TODO: When setting the frequency I should set also the band
+//	cout << "QSO::setFreq: " << tfreq << endl;
+	freq = checkisNotAdif(tfreq);
+}
 
 QString Qso::getFreq() const{
-    return freq;}
+//	cout << "QSO::getFreq: " << freq << endl;
+	return freq;
+}
 
 void Qso::setMode(const QString& tmode){
     mode = checkisNotAdif(tmode);
@@ -178,8 +202,11 @@ QString Qso::getComment()const{
     return comment;}
 
 void Qso::setQslSenDateOn(QDate tdate){
-  qslSen = tdate;
-  qslSenc = 'Y';
+	//cout << "QSO::setQslSenDateOn: " << tdate.toString() << endl;
+	if (tdate.isValid()){
+		qslSen = tdate;
+	}
+	qslSenc = 'Y';
 }
 
 QDate Qso::getQslSenDate() const{
@@ -187,29 +214,38 @@ QDate Qso::getQslSenDate() const{
 }
 
 void Qso::QslSent(const QChar& qslState){
-  qslSenc = qslState;
+	//cout << "QSO:QslSent: " << qslState << endl;
+	qslSenc = qslState;
+}
+
+void Qso::QslRec(const QChar& qslrState){
+	//cout << "QSO:QslRec: " << qslrState << endl;
+
+	qslRecc = qslrState;
 }
 
 QChar Qso::isQslSent(){
-  return  qslSenc;  
+  return  qslSenc;
 }
 
-void Qso::setQslRecDateOn(const QDate tdate){
-  qslRec = tdate;
-  qslRecc = 'Y';
+void Qso::setQslRecDateOn(QDate tdate){
+	//cout << "QSO::setQslRecDateOn: " << tdate.toString() << endl;
+	if (tdate.isValid()){
+		qslRec = tdate;
+	}
+	qslRecc = 'Y';
 }
 
+
+
 QDate Qso::getQslRecDate() const{
   return qslRec;
-  
+
 }
 
-void Qso::QslRec(const QChar& qslState){
-  qslRecc = qslState;
-}
 
 QChar Qso::isQslRec(){
-  return qslRecc;  
+  return qslRecc;
 }
 
 bool Qso::gotTheQSL(){  // Ask if i have his QSL
@@ -227,7 +263,8 @@ bool Qso::sentTheQSL(){ // Did i sent my QSL?
 }
 
 void Qso::setQslVia(const QString &tInfo){
-  qslVia = checkisNotAdif(tInfo);
+	//cout << "QSO::setQslVia: " << tInfo << endl;
+	qslVia = checkisNotAdif(tInfo);
 }
 
 QString Qso::getQslVia() const{
@@ -235,7 +272,8 @@ QString Qso::getQslVia() const{
 }
 
 void Qso::setQslManager(const QString &tqrz){
-  manager = checkisNotAdif(tqrz);
+	//cout << "QSO::setQslManager: " << tqrz << endl;
+	manager = checkisNotAdif(tqrz);
 
 } 
 
@@ -243,16 +281,19 @@ QString Qso::getQslManager() const {
     return manager;}
 
 void Qso::setQslInfo(const QString &tqslInfo){
-  qslInfo = checkisNotAdif(tqslInfo);
+	//cout << "QSO::setQslInfo: " << tqslInfo << endl;
+	qslInfo = checkisNotAdif(tqslInfo);
 
 }
 
 QString Qso::getQslInfo()const{
-    return qslInfo;}
+	return qslInfo;
+}
 
 
 void Qso::setLocator(const QString &tgridSquare ){
-    gridSquare = checkisNotAdif(tgridSquare);
+	//cout << "QSO::setLocator: " << tgridSquare << endl;
+	gridSquare = checkisNotAdif(tgridSquare);
 }
 
 QString Qso::getLocator() const {
@@ -260,7 +301,8 @@ QString Qso::getLocator() const {
 }
 
 void Qso::setMyLocator(const QString &tgridSquare ){
-    myGridSquare = checkisNotAdif(tgridSquare);
+	//cout << "QSO::setMyLocator: " << tgridSquare << endl;
+	myGridSquare = checkisNotAdif(tgridSquare);
 }
 
 QString Qso::getMyLocator() const {
@@ -271,14 +313,16 @@ void Qso::setIota(const QString &tiota){
 // TODO:
 // It is necessary to check the received QString to  allow only valid IOTA
 // references (CC-XXX)
-  iota = checkisNotAdif(tiota);
+	//cout << "QSO::setIota: " << tiota << endl;
+	iota = checkisNotAdif(tiota);
 }
 
 QString Qso::getIota() const{
     return iota;}
 
 void Qso::setLocalAward(const QString &taward){
-  localAward = checkisNotAdif(taward);
+	//cout << "QSO::setLocalAward: " << taward << endl;
+	localAward = checkisNotAdif(taward);
 }
 
 QString Qso::getLocalAward() const{
@@ -344,6 +388,7 @@ QString Qso::getStx_string() const{return stx_string;};
 
 
 void Qso::clearQso(){
+	//cout << "Qso::clearQso" << endl;
 //qrz = "";        // CALL
 //numb = 0;           // STX
 //  QDateTime dateTime; // QSO_DATE/TIME_ON YYYYMMDD - Time HHMM (0000-2359)
@@ -377,7 +422,7 @@ void Qso::clearQso(){
 }
 
 QString Qso::checkisNotAdif(const QString& tword){
-//cout << " - Class Qso::checkAdif" << endl;
+//cout << " - Class Qso::checkAdif" << tword << endl;
 	sAux = tword;
 	if (sAux.contains('<')>0){
 		sAux.replace( QChar('<'), QChar('('));
