@@ -83,7 +83,7 @@ public:
 	void setrxPower(const QString& tpower);
 	QString getrxPower() const;
 
-  void setQslSenDateOn(const QDate tdate);
+  void setQslSenDateOn(QDate tdate);
     QDate getQslSenDate() const;
 
   void QslSent(const QChar& qslState);
@@ -92,7 +92,7 @@ public:
   void setQslRecDateOn(QDate tdate);
   QDate getQslRecDate() const;
 
-  void QslRec(const QChar& qslState);
+  void QslRec(const QChar& qslrState);
   QChar isQslRec();
 
   bool gotTheQSL();  // Ask if i have his QSL
