@@ -49,7 +49,8 @@
 #include "kloghamlib.h"
 #include "award.h"
 #include "awards.h"
-//#include <qthread.h>
+#include <qdialog.h>
+
 
 //#include "hamlib/rig.h"
 
@@ -64,8 +65,6 @@ class Setup : public setupui{
     /** destructor */
     ~Setup();
 
-  public:
-	
   public slots:
   void setRig();
 
